package com.zhentao.hotel.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import lombok.Data;

/**
 * 酒店详情表，存储每个酒店的房间详细信息，包括房间类型、描述、价格等
 * @TableName HotelDetails
 */
@TableName(value ="HotelDetails")
@Data
public class Hoteldetails implements Serializable {
    /**
     * 酒店详情的唯一标识符，自动递增
     */
    @TableId(type = IdType.AUTO)
    private Long detailid;

    /**
     * 关联的酒店ID，外键关联到Hotels表
     */
    private Long hotelid;

    /**
     * 房间类型，如单人间、双人间、套房等
     */
    private String roomtype;

    /**
     * 房间的详细描述，包括设施和服务
     */
    private String roomdescription;

    /**
     * 房间提供的设施，如免费Wi-Fi、空调、迷你吧等
     */
    private String roomamenities;

    /**
     * 房间的价格
     */
    private BigDecimal roomprice;

    /**
     * 房间的大小（平方米）
     */
    private Integer roomsize;

    /**
     * 房间的景观，如城市景观、海景等
     */
    private String roomview;

    /**
     * 房间的最大入住人数
     */
    private Integer roomcapacity;

    /**
     * 是否包含早餐
     */
    private Integer breakfastincluded;

    /**
     * 允许入住的时间
     */
    private Date checkintime;

    /**
     * 必须退房的时间
     */
    private Date checkouttime;

    /**
     * 记录创建时间，默认为当前时间
     */
    private Date createtime;

    /**
     * 记录最后更新时间，默认为当前时间，更新时自动更新
     */
    private Date updatetime;
    private String image;
    @TableField(exist = false)
    private static final long serialVersionUID = 1L;
}
