package com.zhentao.hotel.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

import lombok.Data;

/**
 * 酒店数据表，存储酒店的基本信息、联系方式、分类信息、设施与服务、价格信息、评价与评分等
 * @TableName Hotels
 */
@TableName(value ="Hotels")
@Data
public class Hotels implements Serializable {
    /**
     * ID
     */
    @TableId(type = IdType.AUTO)
    private Long hotelid;

    /**
     * 酒店分类
     */
    private Long sortId;

    /**
     * 酒店名称
     */
    private String hotelname;

    /**
     * 酒店的具体地址
     */
    private String address;

    /**
     * 酒店所在的城市
     */
    private String city;

    /**
     * 酒店所在的州或省
     */
    private String stateprovince;

    /**
     * 酒店所在的国家
     */
    private String country;

    /**
     * 酒店的邮政编码
     */
    private String postalcode;

    /**
     * 酒店的联系电话
     */
    private String phonenumber;

    /**
     * 酒店的电子邮件地址
     */
    private String email;

    /**
     * 酒店的官方网站
     */
    private String website;

    /**
     * 酒店的星级评定
     */
    private Integer starrating;

    /**
     * 酒店的类型（如商务酒店、度假酒店等）
     */
    private String type;

    /**
     * 酒店所属的品牌或连锁
     */
    private String brand;

    /**
     * 酒店提供的设施（如免费Wi-Fi、健身房等）
     */
    private String amenities;

    /**
     * 酒店提供的服务（如客房服务、机场接送等）
     */
    private String services;

    /**
     * 酒店价格
     */
    private BigDecimal price;

    /**
     * 酒店的用户评分
     */
    private BigDecimal rating;

    /**
     * 酒店的评价数量
     */
    private Integer reviewcount;

    /**
     * 酒店的详细描述
     */
    private String description;

    /**
     * 酒店的图片链接
     */
    private String imageurl;

    /**
     * 记录创建时间，默认为当前时间
     */
    private Date createtime;

    /**
     * 记录最后更新时间，默认为当前时间，更新时自动更新
     */
    private Date updatetime;
    @TableField(exist = false)
    private List<Hoteldetails> list;

    @TableField(exist = false)
    private static final long serialVersionUID = 1L;
}
